# hamel

<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

[Hamel’s](https://hamel.dev) python utilities for rapid development.

## Install

``` sh
pip install hamel
```

## How to use

``` python
!oai_list_models --owned openai --limit 15
```

    | Name                    | Created Dt   |
    |:------------------------|:-------------|
    | gpt-4                   | 2023-06-27   |
    | gpt-4-0314              | 2023-06-27   |
    | gpt-4-0613              | 2023-06-12   |
    | gpt-3.5-turbo-0613      | 2023-06-12   |
    | gpt-3.5-turbo-16k-0613  | 2023-05-30   |
    | gpt-3.5-turbo-16k       | 2023-05-10   |
    | tts-1                   | 2023-04-19   |
    | gpt-3.5-turbo-0301      | 2023-02-28   |
    | gpt-3.5-turbo           | 2023-02-28   |
    | whisper-1               | 2023-02-27   |
    | text-embedding-ada-002  | 2022-12-16   |
    | text-davinci-003        | 2022-11-27   |
    | curie-similarity        | 2022-04-28   |
    | babbage-search-document | 2022-04-28   |
    | ada-code-search-text    | 2022-04-28   |

``` python
!oai_new_func --help
```

    usage: oai_new_func [-h] [--name NAME] [--description DESCRIPTION] [--url URL]
                        [--email EMAIL]

    Generate minimal scaffolding for an OpenAI Plugin.

    options:
      -h, --help                 show this help message and exit
      --name NAME                the name of your app for the LLM, ex: `todo`. By
                                 default, this is inferred from the name of your git
                                 repo.
      --description DESCRIPTION  the description of your application that will be
                                 read by the LLM.
      --url URL                  The url of your function endpoint. (default:
                                 http://localhost:8000)
      --email EMAIL              The email associated with your app. By default this
                                 is inferred by git.

``` python
!fetch_site --help
```

    usage: fetch_site [-h] [--to_html] url output_dir

    Fetch content from the specified URL and save it to the given directory. Saves
    the content as a markdown file unless `to_html` is True.

    positional arguments:
      url         The site that you want to fetch documents from
      output_dir  The output directory to write documents to,

    options:
      -h, --help  show this help message and exit
      --to_html   Write output as HTML instead of markdown. (default: False)
